@@ -43,6 +43,7 @@
 #include <QSystemTrayIcon>
 #include <QTranslator>
 #include <QLocale>
+#include <QProcessEnvironment>
 #include "sshmasterconnection.h"
 #include "non_modal_messagebox.h"
 
@@ -885,7 +886,8 @@ private:
     QString xorgWinOptions;
     QString xorgFSOptions;
     QString xorgSAppOptions;
-    enum {WIN,FS,SAPP} xorgMode;
+    QString xorgMDOptions;
+    enum {WIN,FS,SAPP,MULTIDISPLAY} xorgMode;
     QString xorgWidth;
     QString xorgHeight;
     int waitingForX;
@@ -1109,12 +1111,13 @@ private slots:
     void slotRereadUsers();
     void slotExtTimer();
     void slotStartPGPAuth();
-    void slotScDaemonOut();
-    void slotScDaemonError();
+    void slotScDaemonStdOut();
+    void slotScDaemonStdErr();
     void slotGpgFinished ( int exitCode,
                            QProcess::ExitStatus exitStatus );
     void slotScDaemonFinished ( int exitCode,
                                 QProcess::ExitStatus exitStatus );
+    void slotScDaemonError (QProcess::ProcessError error);
     void slotGpgError();
     void slotCheckScDaemon();
     void slotGpgAgentFinished ( int exitCode,
