@@ -93,12 +93,11 @@ QString convert_to_rich_text (const QString &text, bool force) {
   return (fixup_text);
 }
 
-void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text) {
+void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text) {
   QString fixup_main_text (convert_to_rich_text (main_text));
   QString fixup_informative_text (convert_to_rich_text (informative_text, true));
 
-  QMessageBox msg_box (QMessageBox::Warning, QString ("X2Go Client"),
-                       fixup_main_text, NULL);
+  QMessageBox msg_box (icon, QString ("X2Go Client"), fixup_main_text, QMessageBox::Ok);
 
   msg_box.setTextFormat (Qt::RichText);
   msg_box.setInformativeText (fixup_informative_text);
@@ -106,6 +105,14 @@ void show_RichText_WarningMsgBox (const QString &main_text, const QString &infor
   msg_box.exec ();
 }
 
+void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text) {
+  show_RichText_Generic_MsgBox (QMessageBox::Warning, main_text, informative_text);
+}
+
+void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text) {
+  show_RichText_Generic_MsgBox (QMessageBox::Critical, main_text, informative_text);
+}
+
 QString git_changelog_extract_commit_sha (const QString &gitlog) {
   QString ret = "";
 
