@@ -21,6 +21,7 @@
 
 #include <QString>
 #include <QFont>
+#include <QMessageBox>
 
 #define UNUSED(x) do { (void) x; } while (0)
 
@@ -31,7 +32,10 @@ QString fixup_resource_URIs (const QString &res_path);
 QString wrap_legacy_resource_URIs (const QString &res_path);
 
 QString convert_to_rich_text (const QString &text, bool force = false);
+
+void show_RichText_Generic_MsgBox (QMessageBox::Icon icon, const QString &main_text, const QString &informative_text);
 void show_RichText_WarningMsgBox (const QString &main_text, const QString &informative_text = "");
+void show_RichText_ErrorMsgBox (const QString &main_text, const QString &informative_text = "");
 
 QString git_changelog_extract_commit_sha (const QString &gitlog);
 
